@@ -197,7 +197,7 @@ class LongHandlerEN(Operation):
                 sub_len += 1
             if state.current_value in [':', '：'] and sub_len > self.min_sentence_length and self.blank.match(state[i + 1][0]):
                 return i, True
-            if state.current_value == ',':
+            if state.current_value == ',' and not state.next_value.isdigit():
                 # -- 首字母大写优先切分 -- #
                 if state[min(i + 2, length)][0].isupper():
                     best_i = i
